listTagsForResource method
Returns a list of the tags assigned to the specified playback configuration resource.
May throw BadRequestException.
Parameter resourceArn :
The Amazon Resource Name (ARN) for the playback configuration. You can get
this from the response to any playback configuration request.
Implementation
Future<ListTagsForResourceResponse> listTagsForResource({
required String resourceArn,
}) async {
ArgumentError.checkNotNull(resourceArn, 'resourceArn');
final response = await _protocol.send(
payload: null,
method: 'GET',
requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
exceptionFnMap: _exceptionFns,
);
return ListTagsForResourceResponse.fromJson(response);
}