tagResource method

Future<void> tagResource({
  1. required String resourceArn,
  2. required Map<String, String> tags,
})

Adds tags to the specified playback configuration resource. You can specify one or more tags to add.

May throw BadRequestException.

Parameter resourceArn : The Amazon Resource Name (ARN) for the playback configuration. You can get this from the response to any playback configuration request.

Parameter tags : A comma-separated list of tag key:value pairs. For example: { "Key1": "Value1", "Key2": "Value2" }

Implementation

Future<void> tagResource({
  required String resourceArn,
  required Map<String, String> tags,
}) async {
  ArgumentError.checkNotNull(resourceArn, 'resourceArn');
  ArgumentError.checkNotNull(tags, 'tags');
  final $payload = <String, dynamic>{
    'tags': tags,
  };
  await _protocol.send(
    payload: $payload,
    method: 'POST',
    requestUri: '/tags/${Uri.encodeComponent(resourceArn)}',
    exceptionFnMap: _exceptionFns,
  );
}